Clean model implementations using solid abstractions Models V2 - Clean implementations using solid abstractions
This module contains model implementations that use our new solid abstractions:
- TensorCore for unified tensor operations
- ModelCore for clean model interfaces
- WeightLoaderCore for format-agnostic weight loading
All models in this module implement the Model trait and use consistent patterns.
Modules
- arctic
- Arctic Model V2 - Clean implementation
- baichuan
- Baichuan Model V2 - Clean implementation using solid abstractions
- bert
- BERT Model V2 - Clean implementation using solid abstractions
- bloom
- BLOOM Model V2 - Clean implementation
- chatglm
- ChatGLM Model V2 - Clean implementation using solid abstractions
- clip
- CLIP Model V2 - Clean implementation using solid abstractions
- codellama
- CodeLlama Model V2 - Clean implementation
- cogvlm
- CogVLM Model V2 - Vision-Language Model with Expert Attention
- dbrx
- DBRX Model V2 - Clean implementation
- deepseek
- DeepSeek Model V2 - Clean implementation using solid abstractions
- deepseek_
moe - DeepSeek-MoE Model V2 - Clean implementation
- encodec
- EnCodec Model V2 - Neural Audio Codec
- falcon
- Falcon Model V2 - Clean implementation using solid abstractions
- florence
- Florence Model V2 - Microsoft Vision-Language Foundation Model
- gemma
- Gemma Model V2 - Clean implementation using solid abstractions
- gpt2
- GPT-2 Model V2 - Clean implementation using solid abstractions
- gptj
- GPT-J Model V2 - Clean implementation using solid abstractions
- gptneox
- GPT-NeoX Model V2 - Clean implementation
- granite
- Granite Model V2 - Clean implementation
- grok
- Grok Model V2 - Clean implementation
- hubert
- HuBERT Model V2 - Hidden-Unit BERT for Self-Supervised Speech
- idefics
- Idefics Model V2 - HuggingFace Vision-Language Model with Cross-Attention
- internlm
- InternLM Model V2 - Clean implementation using solid abstractions
- internvl
- InternVL Model V2 - Vision-Language Model
- jamba
- Jamba Model V2 - Hybrid Mamba-Transformer with MoE
- llama
- Llama Model V2 - Clean implementation using solid abstractions
- llava
- LLaVA Model V2 - Clean implementation using solid abstractions
- mamba
- Mamba Model V2 - State-Space Model implementation
- minicpm
- MiniCPM Model V2 - Clean implementation using solid abstractions
- mistral
- Mistral Model V2 - Clean implementation using solid abstractions
- mixtral
- Mixtral Model V2 - Clean implementation using solid abstractions
- mpt
- MPT Model V2 - Clean implementation
- musicgen
- MusicGen Model V2 - Music Generation with EnCodec Tokens
- olmo
- OLMo Model V2 - Clean implementation
- opt
- OPT Model V2 - Clean implementation
- phi
- Phi Model V2 - Clean implementation using solid abstractions
- phi3_
vision - Phi-3-Vision Model V2 - Vision-Language Model
- qwen
- Qwen Model V2 - Clean implementation using solid abstractions
- qwen2_
vl - Qwen2-VL Model V2 - Vision-Language Model
- recurrent_
gemma - RecurrentGemma Model V2 - Griffin Architecture with Linear Recurrence
- rwkv4
- RWKV-4 Model V2 - Linear Attention with Time and Channel Mixing
- rwkv6
- RWKV-6 Model V2 - Linear Attention with Matrix-Valued States
- starcoder
- StarCoder Model V2 - Clean implementation
- t5
- T5 Model V2 - Clean implementation using solid abstractions
- traits
- Common traits and utilities for V2 model implementations
- wav2vec2
- Wav2Vec2 Model V2 - Self-Supervised Audio Encoder
- whisper
- Whisper Model V2 - Clean implementation using solid abstractions
- yi
- Yi Model V2 - Clean implementation using solid abstractions