LlamaModelV2

Struct LlamaModelV2 

pub struct LlamaModelV2 { /* private fields */ }
Main Llama model implementation

Implementations

Source

impl LlamaModelV2

pub fn forward_with_cache( &self, inputs: &ModelInputs, cache: Option<&mut KVCache>, ) -> Result<ModelOutputs>

Forward pass with KV cache support

This method enables efficient autoregressive generation by caching Key and Value tensors from previous tokens.

Arguments
  • inputs - Model inputs (only new tokens)
  • cache - Optional mutable reference to KV cache
Returns

Model outputs with logits for the new tokens

pub fn generate_with_cache( &self, prompt: &str, config: &GenerationConfig, ) -> Result<String>

Generate text with KV caching for efficient autoregressive generation

This method is significantly faster than generate() for long sequences because it caches Key and Value tensors instead of recomputing them.

Arguments
  • prompt - Input text prompt
  • config - Generation configuration
Returns

Generated text including the prompt