pub struct SlidingWindowMaskCache { /* private fields */ }Expand description
Precomputed sliding window attention mask
Each position can only attend to the previous window_size positions.
Used by Mistral, Mixtral, and other sliding window attention models.
Implementations
Sourceimpl SlidingWindowMaskCache
impl SlidingWindowMaskCache
Sourcepub fn new(
max_seq_len: usize,
window_size: usize,
device: &Device,
) -> Result<Self>
pub fn new( max_seq_len: usize, window_size: usize, device: &Device, ) -> Result<Self>
Create a new sliding window mask cache
Arguments
max_seq_len- Maximum sequence length to precomputewindow_size- Number of positions to attend todevice- Device to store the mask on
Sourcepub fn get(&self, seq_len: usize) -> Result<Tensor>
pub fn get(&self, seq_len: usize) -> Result<Tensor>
Get sliding window mask for a specific sequence length
Sourcepub fn get_broadcast(&self, seq_len: usize) -> Result<Tensor>
pub fn get_broadcast(&self, seq_len: usize) -> Result<Tensor>
Get sliding window mask reshaped for attention broadcasting
Sourcepub fn window_size(&self) -> usize
pub fn window_size(&self) -> usize
Get the window size
Sourcepub fn max_seq_len(&self) -> usize
pub fn max_seq_len(&self) -> usize
Get the maximum sequence length