pub struct Installer { /* private fields */ }
A thread installer that is passed to a Threadable when installing the threads into the Runtime

Implementations

Spawn a new thread with a name. The installer function callback will be called with a Notifier and is returns the thread function.