pub struct Notifier { /* private fields */ }
A thread status notifier, that allows a thread to notify the Runtime of the current status of the thread.

Implementations

Notify the Runtime that the thread is busy processing.

Notify the Runtime to request that the Runtime and all other registered thread pause processing.

Notify the Runtime to request that the Runtime and all other registered thread resume processing.

Notify the Runtime to request that the Runtime and all other registered thread end processing.

Notify the Runtime that the thread is waiting for new data or messages to process.

Notify the Runtime that the thread is in a permanent error state.

Notify the Runtime that the thread has ended processing.