pub struct Runtime<'runtime> { /* private fields */ }
A system the manages the lifetime of threads. This includes ensuring errors are handled, threads are paused and resumed on request and that once the main application is completed, all threads complete and end.

Implementations

Create a new instances of the Runtime.

Get a cloned copy of the ThreadStatuses.

Register a new Threadable.

Join the runtime thread, waiting for all threads to finish.

Errors

Returns and error if any of the threads registered to the runtime produce an error.