pub struct ThreadableTester { /* private fields */ }
A tester utility for Threadable.

Implementations

Create a new instance of the test utility.

Take the current Status changes.

Start a Threadable running the thread specified by the name, to completion in a separate thread.

Wait for a particular status to be reached.

Panics

Will panic if the wait takes too long and times out.

Wait for the thread started in start_threadable to finish.

Panics

Will panic if the wait takes too long and times out.