Module weight_loader_core

Module weight_loader_core 

Weight loading from various formats Core Weight Loading Abstraction

This module provides unified weight loading that converts any supported weight format into our core tensor abstraction.

Structs

ConfigLoader
Model configuration loader - loads config.json files
GGUFModelConfig
Configuration extracted from GGUF metadata
GGUFSpecialTokens
Special token IDs extracted from GGUF
GGUFTokenizer
Tokenizer data extracted from GGUF metadata
GGUFWeightLoader
GGUF weight loader
ModelLoader
Complete model loading pipeline
PyTorchWeightLoader
PyTorch weight loader
SafeTensorsWeightLoader
SafeTensors weight loader
UnifiedWeightLoader
Unified weight loader that dispatches to appropriate format loaders

Traits

WeightLoader
Core weight loader trait - abstracts loading from different formats

Functions

loader
Get global model loader