pub struct Notifier { /* private fields */ }Expand description
A thread status notifier, that allows a thread to notify the Runtime of the current status of the thread.
Implementations
sourceimpl Notifier
impl Notifier
sourcepub fn request_pause(&self)
pub fn request_pause(&self)
Notify the Runtime to request that the Runtime and all other registered thread pause processing.
sourcepub fn request_resume(&self)
pub fn request_resume(&self)
Notify the Runtime to request that the Runtime and all other registered thread resume processing.
sourcepub fn request_end(&self)
pub fn request_end(&self)
Notify the Runtime to request that the Runtime and all other registered thread end processing.
sourcepub fn wait(&self)
pub fn wait(&self)
Notify the Runtime that the thread is waiting for new data or messages to process.