pub struct Runtime<'runtime> { /* private fields */ }Expand description
A system the manages the lifetime of threads. This includes ensuring errors are handled, threads are paused and resumed on request and that once the main application is completed, all threads complete and end.
Implementations
sourceimpl<'runtime> Runtime<'runtime>
impl<'runtime> Runtime<'runtime>
sourcepub fn statuses(&self) -> ThreadStatuses
pub fn statuses(&self) -> ThreadStatuses
Get a cloned copy of the ThreadStatuses.
sourcepub fn register(&self, threadable: &'runtime mut dyn Threadable)
pub fn register(&self, threadable: &'runtime mut dyn Threadable)
Register a new Threadable.