Struct runtime::testutils::ThreadableTester
source · [−]pub struct ThreadableTester { /* private fields */ }Expand description
A tester utility for Threadable.
Implementations
sourceimpl ThreadableTester
impl ThreadableTester
sourcepub fn take_statuses(&self) -> Vec<Status>
pub fn take_statuses(&self) -> Vec<Status>
Take the current Status changes.
sourcepub fn start_threadable<Threadable: Threadable>(
&self,
theadable: &Threadable,
thread_name: &str
)
pub fn start_threadable<Threadable: Threadable>(
&self,
theadable: &Threadable,
thread_name: &str
)
Start a Threadable running the thread specified by the name, to completion in a separate thread.
sourcepub fn wait_for_status(&self, status: &Status)
pub fn wait_for_status(&self, status: &Status)
Wait for a particular status to be reached.
Panics
Will panic if the wait takes too long and times out.
sourcepub fn wait_for_finished(&self)
pub fn wait_for_finished(&self)
Wait for the thread started in start_threadable to finish.
Panics
Will panic if the wait takes too long and times out.