pub trait Threadable: Send {
// Required method
fn install(&self, installer: &Installer);
// Provided methods
fn pause(&self) { ... }
fn resume(&self) { ... }
fn end(&self) { ... }
}Expand description
An interface for a entity that has threads managed by the Runtime.
Required Methods
Provided Methods
Sourcefn pause(&self)
fn pause(&self)
Called when threads are requested to pause.
Errors
Returns an error is that thread cannot be paused for any reason.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".